==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/bs.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenti",
"Can't create document" => "Nemoguće kreirati dokument",
"You don't have permission to rename this document" => "Niste ovlašteni preimenovati ovaj dokument",
"Directory saved successfully." => "Direktorij uspješno spremljen.",
"An error occurred while changing directory." => "Greška pri izmjeni direktorija.",
"Saved" => "Spremljeno",
"Format filter server is down or misconfigured" => "Server za filtriranje formata je pao ili je pogrešno konfigurisan",
"Conversion failed. Check log for details." => "Pretvorba nije uspjela. Za detalje provjerite zapisnik (log).",
"Saving..." => "Spremanje...",
"Failed to load documents." => "Učitavanje dokumenata nije uspjelo.",
"No documents were found. Upload or create a document to get started!" => "Dokumenti nisu nađeni. Za početak, učitajte ili kreirajte neki dokument!",
"No connection to server. Trying to reconnect." => "Nema konekcije sa serverom. Ponovo pokušavanje uspostavljanja veze.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Napuštanje ove stranice u načinu rada za izmjene može rezultirati nespremljenim podacima. Umjesto toga, preporučuje se pritisnuti dugme 'Zatvori'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Učitavanje ovog dokumenta nije uspjelo. Molim provjerite može li se otvoriti s nekim vanjskim odt uređivačem. To također može značiti da je njegovo dijeljenje zaustavljeno ili da je izbrisan.",
"Save" => "Spremi",
"Loading documents..." => "Učitavanje dokumenata...",
"'.' is an invalid file name." => "'.' nije validan naziv datoteke.",
"File name cannot be empty." => "Naziv datoteke ne može biti prazan",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Neispravan naziv, '\\', '/', '<', '>', ':', '\"', '|', '?'  i '*' nisu dopušteni.",
"Align Left" => "Svrstaj slijeva",
"Alignment" => "Svrstavanje",
"Align Right" => "Svrstavanje sdesna",
"Annotate" => "Stavite primjedbu",
"Background" => "Pozadina",
"Bold" => "Podebljano",
"Bottom" => "Dno",
"Cancel" => "Odustani",
"Center" => "Centar",
"Clone" => "Kloniraj",
"Clone this Style" => "KLoniraj ovaj Stil",
"Close" => "Zatvori",
"Color" => "Boja",
"Create" => "Kreiraj",
"Decrease Indent" => "Smanji uvlaku",
"Default Style" => "Uobičajen Stil",
"Delete" => "Izbriši",
"Family" => "Obitelj",
"Font" => "Pismo",
"Font Effects" => "Efekti Pisma",
"Format" => "Format",
"Increase Indent" => "Povećaj Uvlaku",
"Insert Image" => "Umetni Sliku",
"Invite Members" => "Pozovi Članove",
"Italic" => "Kurziv",
"Justified" => "Opravdano",
"Justify" => "Opravdaj",
"Left" => "Lijevo",
"Loading" => "Učitavanje",
"Members" => "Članovi",
"New Name:" => "Novi naziv:",
"OK" => "OK",
"Open" => "Otvori",
"Options" => "Postavke",
"Paragraph..." => "Odlomak",
"Paragraph Styles" => "Stilovi odlomka",
"Redo" => "Ponovi",
"Right" => "Desno",
"Size" => "Veličina",
"Spacing" => "Razmak",
"Strikethrough" => "Precrtaj",
"Style" => "Stil",
"Text" => "Tekst",
"Top" => "Vrh",
"Underline" => "Podcrtaj",
"Undo" => "Poništi",
"Unknown Author" => "Nepoznat Autor",
"Edit" => "Izmjeni",
"Share" => "Podijeli",
"guest" => "gost",
"MS Word support (requires openOffice/libreOffice)" => "MS Word podrška (obavezan openOffice/libreOffice)",
"Local" => "Lokalno",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice je instaliran na ovom serveru. Put do binarnog omogućen je putem preview_libreoffice_path u config.php",
"External" => "Vanjsko",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice je instaliran na vanjskom serveru koji pokreće server filtriranje formata",
"Disabled" => "Onemogućeno",
"No MS Word support" => "Nema MS Word podrške",
"scheme://domain.tld[:port]" => "šema: //domain.tld[:port]",
"Server URL" => "Server URL",
"Apply and test" => "Primijeni i testiraj",
"New document" => "Novi dokument",
"Upload (max. %s)" => "Učitaj (max. %s)",
"Upload" => "Učitaj",
"Save new documents to" => "Spremi nove dokumente pod",
"Wrong password. Please retry." => "Pogrešna lozinka. Molim pokušajte ponovo",
"Password" => "Lozinka",
"Guest %s" => "Gost %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Ova veza je istekla ili nikad nije postojala. Za detalje, molim kontaktirajte osobu koja ju je s vama podijelila.",
"Advanced feature-set" => "Napredan skup značajki",
"(Unstable)" => "(Nestabilno)"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";

==> owncloud-app-documents-1%3A9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/bs.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Dokumenti",
"Can't create document" => "Nemoguće kreirati dokument",
"You don't have permission to rename this document" => "Niste ovlašteni preimenovati ovaj dokument",
"Directory saved successfully." => "Direktorij uspješno spremljen.",
"An error occurred while changing directory." => "Greška pri izmjeni direktorija.",
"Saved" => "Spremljeno",
"Format filter server is down or misconfigured" => "Server za filtriranje formata je pao ili je pogrešno konfigurisan",
"Conversion failed. Check log for details." => "Pretvorba nije uspjela. Za detalje provjerite zapisnik (log).",
"Saving..." => "Spremanje...",
"Failed to load documents." => "Učitavanje dokumenata nije uspjelo.",
"No documents were found. Upload or create a document to get started!" => "Dokumenti nisu nađeni. Za početak, učitajte ili kreirajte neki dokument!",
"No connection to server. Trying to reconnect." => "Nema konekcije sa serverom. Ponovo pokušavanje uspostavljanja veze.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Napuštanje ove stranice u načinu rada za izmjene može rezultirati nespremljenim podacima. Umjesto toga, preporučuje se pritisnuti dugme 'Zatvori'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Učitavanje ovog dokumenta nije uspjelo. Molim provjerite može li se otvoriti s nekim vanjskim odt uređivačem. To također može značiti da je njegovo dijeljenje zaustavljeno ili da je izbrisan.",
"Save" => "Spremi",
"Loading documents..." => "Učitavanje dokumenata...",
"'.' is an invalid file name." => "'.' nije validan naziv datoteke.",
"File name cannot be empty." => "Naziv datoteke ne može biti prazan",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Neispravan naziv, '\\', '/', '<', '>', ':', '\"', '|', '?'  i '*' nisu dopušteni.",
"Align Left" => "Svrstaj slijeva",
"Alignment" => "Svrstavanje",
"Align Right" => "Svrstavanje sdesna",
"Annotate" => "Stavite primjedbu",
"Background" => "Pozadina",
"Bold" => "Podebljano",
"Bottom" => "Dno",
"Cancel" => "Odustani",
"Center" => "Centar",
"Clone" => "Kloniraj",
"Clone this Style" => "KLoniraj ovaj Stil",
"Close" => "Zatvori",
"Color" => "Boja",
"Create" => "Kreiraj",
"Decrease Indent" => "Smanji uvlaku",
"Default Style" => "Uobičajen Stil",
"Delete" => "Izbriši",
"Family" => "Obitelj",
"Font" => "Pismo",
"Font Effects" => "Efekti Pisma",
"Format" => "Format",
"Increase Indent" => "Povećaj Uvlaku",
"Insert Image" => "Umetni Sliku",
"Invite Members" => "Pozovi Članove",
"Italic" => "Kurziv",
"Justified" => "Opravdano",
"Justify" => "Opravdaj",
"Left" => "Lijevo",
"Loading" => "Učitavanje",
"Members" => "Članovi",
"New Name:" => "Novi naziv:",
"OK" => "OK",
"Open" => "Otvori",
"Options" => "Postavke",
"Paragraph..." => "Odlomak",
"Paragraph Styles" => "Stilovi odlomka",
"Redo" => "Ponovi",
"Right" => "Desno",
"Size" => "Veličina",
"Spacing" => "Razmak",
"Strikethrough" => "Precrtaj",
"Style" => "Stil",
"Text" => "Tekst",
"Top" => "Vrh",
"Underline" => "Podcrtaj",
"Undo" => "Poništi",
"Unknown Author" => "Nepoznat Autor",
"Shared" => "Podijeljen",
"Error" => "Greška",
"Error while sharing" => "Greška pri dijeljenju",
"Error while unsharing" => "Ggreška pri prestanku dijeljenja",
"Error while changing permissions" => "Greška pri mijenjanju dozvola",
"Shared with you and the group {group} by {owner}" => "Dijeljeno s vama i grupom {group} vlasnika {owner}",
"Shared with you by {owner}" => "Podijeljeno sa vama od {owner}",
"Share" => "Podijeli",
"Share link" => "Podijelite vezu",
"The public link will expire no later than {days} days after it is created" => "Javna veza ističe najkasnije {days} dana nakon što je kreirana",
"Link" => "Veza",
"Password protect" => "Zaštitita lozinkom",
"Password" => "Lozinka",
"Choose a password for the public link" => "Izaberite lozinku za javnu vezu",
"Allow editing" => "Dozvolite izmjenu",
"Email link to person" => "Pošaljite osobi vezu e-poštom",
"Send" => "Pošalji",
"Set expiration date" => "Postavite datum isteka",
"Expiration" => "Istek",
"Expiration date" => "Datum isteka",
"Adding user..." => "Dodavanje korisnika...",
"group" => "grupa",
"remote" => "daljinski",
"Resharing is not allowed" => "Ponovno dijeljenje nije dopušteno",
"Shared in {item} with {user}" => "Podijeljeno u {item} s {user}",
"Unshare" => "Prestani  dijeliti",
"notify by email" => "Obavijesti e-poštom",
"can share" => "mogu dijeliti",
"can edit" => "mogu mijenjati",
"access control" => "Kontrola pristupa",
"create" => "kreiraj",
"change" => "izmjeni",
"delete" => "izbriši",
"Password protected" => "Zaštićeno lozinkom",
"Error unsetting expiration date" => "Pogrešno uklanjanje postavke datuma isteka",
"Error setting expiration date" => "Pogrešno postavljanje datuma isteka",
"Sending ..." => "Slanje...",
"Email sent" => "E-pošta je poslana",
"Warning" => "Upozorenje",
"Edit" => "Izmjeni",
"guest" => "gost",
"MS Word support (requires openOffice/libreOffice)" => "MS Word podrška (obavezan openOffice/libreOffice)",
"Local" => "Lokalno",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice je instaliran na ovom serveru. Put do binarnog omogućen je putem preview_libreoffice_path u config.php",
"External" => "Vanjsko",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice je instaliran na vanjskom serveru koji pokreće server filtriranje formata",
"Disabled" => "Onemogućeno",
"No MS Word support" => "Nema MS Word podrške",
"scheme://domain.tld[:port]" => "šema: //domain.tld[:port]",
"Server URL" => "Server URL",
"Apply and test" => "Primijeni i testiraj",
"New document" => "Novi dokument",
"Upload (max. %s)" => "Učitaj (max. %s)",
"Upload" => "Učitaj",
"Save new documents to" => "Spremi nove dokumente pod",
"Wrong password. Please retry." => "Pogrešna lozinka. Molim pokušajte ponovo",
"Guest %s" => "Gost %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Ova veza je istekla ili nikad nije postojala. Za detalje, molim kontaktirajte osobu koja ju je s vama podijelila.",
"Advanced feature-set" => "Napredan skup značajki",
"(Unstable)" => "(Nestabilno)"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
